@@ -39,14 +39,11 @@ typedef struct _GtkSourceCompletionContextPrivate	GtkSourceCompletionContextPriv
 
 /**
  * GtkSourceCompletionActivation:
- * @GTK_SOURCE_COMPLETION_ACTIVATION_NONE: None.
- * @GTK_SOURCE_COMPLETION_ACTIVATION_INTERACTIVE: Interactive activation. By
- * default, it occurs on each insertion in the #GtkTextBuffer. This can be
- * blocked temporarily with gtk_source_completion_block_interactive().
- * @GTK_SOURCE_COMPLETION_ACTIVATION_USER_REQUESTED: User requested activation.
- * By default, it occurs when the user presses
- * <keycombo><keycap>Control</keycap><keycap>space</keycap></keycombo>.
- */
+ * @GTK_SOURCE_COMPLETION_ACTIVATION_NONE: none.
+ * @GTK_SOURCE_COMPLETION_ACTIVATION_INTERACTIVE: interactive activation
+ * @GTK_SOURCE_COMPLETION_ACTIVATION_USER_REQUESTED: user requested activation
+ * (e.g. through a keyboard accelerator from the view)
+ **/
 typedef enum
 {
 	GTK_SOURCE_COMPLETION_ACTIVATION_NONE = 0,
@@ -78,7 +75,7 @@ void 		 gtk_source_completion_context_add_proposals 	(GtkSourceCompletionContext
 								 GList                        *proposals,
 								 gboolean                      finished);
 
-gboolean	 gtk_source_completion_context_get_iter		(GtkSourceCompletionContext   *context,
+void		 gtk_source_completion_context_get_iter		(GtkSourceCompletionContext   *context,
 								 GtkTextIter                  *iter);
 
 GtkSourceCompletionActivation
