@@ -619,8 +619,8 @@ on_proposal_changed (GtkSourceCompletionProposal *proposal,
 }
 
 void
-gtk_source_completion_model_begin (GtkSourceCompletionModel *model,
-                                   GList                    *providers)
+gtk_source_completion_model_begin_populate (GtkSourceCompletionModel *model,
+					    GList                    *providers)
 {
 	g_return_if_fail (GTK_SOURCE_IS_COMPLETION_MODEL (model));
 
@@ -1183,9 +1183,9 @@ add_provider_info (GtkSourceCompletionModel    *model,
 }
 
 void
-gtk_source_completion_model_append (GtkSourceCompletionModel    *model,
-                                    GtkSourceCompletionProvider *provider,
-                                    GList                       *proposals)
+gtk_source_completion_model_add_proposals (GtkSourceCompletionModel    *model,
+					   GtkSourceCompletionProvider *provider,
+					   GList                       *proposals)
 {
 	GList *item;
 	ProviderInfo *info;
@@ -1281,8 +1281,8 @@ gtk_source_completion_model_append (GtkSourceCompletionModel    *model,
 }
 
 void
-gtk_source_completion_model_end (GtkSourceCompletionModel    *model,
-                                 GtkSourceCompletionProvider *provider)
+gtk_source_completion_model_end_populate (GtkSourceCompletionModel    *model,
+					  GtkSourceCompletionProvider *provider)
 {
 	/* Remove unmarked proposals, returns TRUE if there are any proposals
 	 * left for 'provider'. If so, we add 'provider' to the list of
@@ -1365,15 +1365,16 @@ provider_has_proposals (GtkSourceCompletionProvider *provider,
 	}
 }
 
+/* If @only_visible is %TRUE, only the visible providers are taken into account. */
 gboolean
 gtk_source_completion_model_is_empty (GtkSourceCompletionModel *model,
-                                      gboolean                  invisible)
+                                      gboolean                  only_visible)
 {
 	gboolean isempty = TRUE;
 
 	g_return_val_if_fail (GTK_SOURCE_IS_COMPLETION_MODEL (model), FALSE);
 
-	if (!invisible)
+	if (only_visible)
 	{
 		g_hash_table_foreach (model->priv->providers_info,
 		                      (GHFunc)provider_has_proposals,
@@ -1488,6 +1489,9 @@ gtk_source_completion_model_iter_last (GtkSourceCompletionModel *model,
 	}
 }
 
+/* Get all the providers (visible and hidden), sorted by priority in descending
+ * order (the highest priority first).
+ */
 GList *
 gtk_source_completion_model_get_providers (GtkSourceCompletionModel *model)
 {
